@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # pebble - Passman client
-# Copyright (C) 2018,2019,2020,2021 Damien Goutte-Gattat
+# Copyright (C) 2018,2019,2020,2021,2022 Damien Goutte-Gattat
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ except:
 prog_name = "pbl"
 prog_notice = f"""\
 {prog_name} (Pebble {__version__})
-Copyright © 2018–2021 Damien Goutte-Gattat
+Copyright © 2018–2022 Damien Goutte-Gattat
 
 This program is released under the GNU General Public License.
 See the COPYING file or <http://www.gnu.org/licenses/gpl.html>.
@@ -354,6 +354,7 @@ def export(pbl, filename):
     else:
         raise Error("Decryption failed")
 
+
 @pebble.command()
 @click.option('--json', '-j', is_flag=True, default=False,
               help="Edit new credential as JSON.")
@@ -381,6 +382,7 @@ def new(pbl, json):
         'files': [],
         'custom_fields': [],
         'otp': {},
+        'compromised': False,
         'hidden': False
         }
     newcred = edit_credential(template, json)
@@ -417,8 +419,10 @@ _fields = [
 @click.option('--id', '-i', 'show_id', default=-1, type=click.INT,
               metavar="ID",
               help="Show the credential with the specified ID.")
+@click.option('--only-password', '-p', is_flag=True, default=False,
+              help="Only show the password itself")
 @click.pass_obj
-def show(pbl, patterns, show_id):
+def show(pbl, patterns, show_id, only_password):
     """Show credential(s).
     
     This command shows the credentials matching the given pattern(s);
@@ -430,6 +434,10 @@ def show(pbl, patterns, show_id):
     else:
         creds = pbl.vault.search(patterns, decrypt=True)
     for cred in creds:
+        if only_password:
+            print(cred['password'])
+            break
+
         print(f"+---- {cred['label']} ({cred['credential_id']}) -----")
         for field_name, field_label, field_format in _fields:
             if cred[field_name]:
